==> bitcoin-23.0.tar.gz: bitcoin-23.0/src/qt/locale/bitcoin_my.ts <==
<TS version="2.1" language="my">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">လိပ်စာ သို့မဟုတ် ခေါင်းစဉ်တပ်ရန် Right-click နှိပ်ပါ။</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">လိပ်စာအသစ်ယူမယ်။</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;အသစ်</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">လက်ရှိရွေးထားတဲ့ လိပ်စာကို clipboard ပေါ်တင်မယ်။</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;ကူးမယ်</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">ပိတ်မည်</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">လက်ရှိရွေးထားတဲ့ လိပ်စာကို ဖျက်မယ်။</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">လိပ်စာရိုက်ထည့်ပါ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">လက်ရှိ tab မှာရှိတဲ့ဒေတာတွေကို ဖိုင်လ်မှာသိမ်းမယ်။</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;ထုတ်ယူသိမ်းဆည်း</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;ဖျက်</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">လိပ်စာကိုပေးပို့ဖို့လိပ်စာရွေးချယ်ပါ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">ဒင်္ဂါးများလက်ခံရယူမည့်လိပ်စာကို​​ရွေးပါ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">​ရွေးပါ</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">လိပ်စာပေးပို့နေသည်</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">လိပ်စာလက်ခံရရှိသည်</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">တင်ပို့မှုမအောင်မြင်ပါ</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">တံဆိပ်</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">လိပ်စာ</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">အမှား</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">သတိပေးချက်</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">အချက်အလက်</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">နောက်ဆုံးပေါ်</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">ချဲ့</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">နေ့စွဲ</translation>
    </message>
    <message>
        <source>yes</source>
        <translation type="unfinished">ဟုတ်တယ်</translation>
    </message>
    <message>
        <source>no</source>
        <translation type="unfinished">မဟုတ်ဘူး</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">အမှား</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">အမှား</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">လိပ်စာ</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">နေ့စွဲ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">တံဆိပ်</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">နေ့စွဲ</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">နေ့စွဲ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">တံဆိပ်</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Other</source>
        <translation type="unfinished">အခြား</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">နေ့စွဲ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">တံဆိပ်</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">လိပ်စာ</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">တင်ပို့မှုမအောင်မြင်ပါ</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">အမှား</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;ထုတ်ယူသိမ်းဆည်း</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">လက်ရှိ tab မှာရှိတဲ့ဒေတာတွေကို ဖိုင်လ်မှာသိမ်းမယ်။</translation>
    </message>
    </context>
</TS>

==> bitcoin-25.1.tar.gz: bitcoin-25.1/src/qt/locale/bitcoin_my.ts <==
<TS version="2.1" language="my">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">လိပ်စာ သို့မဟုတ် ခေါင်းစဉ်တပ်ရန် Right-click နှိပ်ပါ။</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">လိပ်စာအသစ်ယူမယ်။</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;အသစ်</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">လက်ရှိရွေးထားတဲ့ လိပ်စာကို clipboard ပေါ်တင်မယ်။</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;ကူးမယ်</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">ပိတ်မည်</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">လက်ရှိရွေးထားတဲ့ လိပ်စာကို ဖျက်မယ်။</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">လိပ်စာရိုက်ထည့်ပါ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">လက်ရှိ tab မှာရှိတဲ့ဒေတာတွေကို ဖိုင်လ်မှာသိမ်းမယ်။</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;ထုတ်ယူသိမ်းဆည်း</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;ဖျက်</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">လိပ်စာကိုပေးပို့ဖို့လိပ်စာရွေးချယ်ပါ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">ဒင်္ဂါးများလက်ခံရယူမည့်လိပ်စာကို​​ရွေးပါ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">​ရွေးပါ</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">လိပ်စာပေးပို့နေသည်</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">လိပ်စာလက်ခံရရှိသည်</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;ပြင်ဆင်</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">တင်ပို့မှုမအောင်မြင်ပါ</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">တံဆိပ်</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">လိပ်စာ</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">အမှား-%1</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">အမှား</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">သတိပေးချက်</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">အချက်အလက်</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">နောက်ဆုံးပေါ်</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">ချဲ့</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">အမှား-%1</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">နေ့စွဲ</translation>
    </message>
    <message>
        <source>yes</source>
        <translation type="unfinished">ဟုတ်တယ်</translation>
    </message>
    <message>
        <source>no</source>
        <translation type="unfinished">မဟုတ်ဘူး</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">အမှား</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">အမှား</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">လိပ်စာ</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">နေ့စွဲ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">တံဆိပ်</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">နေ့စွဲ</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">နေ့စွဲ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">တံဆိပ်</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Other</source>
        <translation type="unfinished">အခြား</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">နေ့စွဲ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">တံဆိပ်</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">လိပ်စာ</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">တင်ပို့မှုမအောင်မြင်ပါ</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">အမှား</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;ထုတ်ယူသိမ်းဆည်း</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">လက်ရှိ tab မှာရှိတဲ့ဒေတာတွေကို ဖိုင်လ်မှာသိမ်းမယ်။</translation>
    </message>
    </context>
</TS>
